@@ -9,7 +9,7 @@
 #include "../jammo-cursor.h"
 #include "../jammo-mentor.h"
 #include "../jammo.h"
-#include "../save_helper.h"
+#include "../file_helper.h"
 
 #include "chum.h" //chum_is_easy_game
 #include "theme.h"
@@ -85,10 +85,12 @@ static gboolean save_image_pressed(TangleButton *tanglebutton, gpointer data){
 	gchar* filename_for_saving = g_strdup_printf("+%s+%d+%s-",theme->name,theme->variation,chum_is_easy_game()?"e":"a");
 	//e.g.: +fantasy+2+e-
 
-	gchar* additional_metadata = g_strdup_printf("\"icon\" : \"%s\",\n\"theme\" : \"%s\",\n\"variation\" : %d,\n",name_of_icon,theme->name,theme->variation);
+	gchar* additional_metadata = g_strdup_printf("\"icon\" : \"%s\",\n\
+\"theme\" : \"%s\",\n\
+\"variation\" : %d,\n"\
+  ,name_of_icon,theme->name,theme->variation);
 
-	//save composition will return filename, but we are not interested in
-	g_free(save_composition(filename_for_saving, clutter_actor_get_parent(CLUTTER_ACTOR(theme->bottom_track_view)) ,additional_metadata));
+	save_composition(configure_get_compositions_directory(),filename_for_saving, clutter_actor_get_parent(CLUTTER_ACTOR(theme->bottom_track_view)) ,additional_metadata);
 
 	g_free(filename_for_saving);
 	g_free(additional_metadata);
