@@ -19,21 +19,20 @@ void helpdesk_goto_communitymenu(TangleButton *tanglebutton, gpointer none);
 void helpdesk_goto_startmenu(TangleButton *tanglebutton, gpointer none);
 
 //Functions for creating and moving loops
-gboolean helpdesk_add_loop_to_list(char* loopName, int numberOfLoops);
+gboolean helpdesk_add_loop_to_list(gpointer data, int index, int previousindex);
 void helpdesk_autoscroll_to_correct_pos(ClutterActor *listToScroll);
 void helpdesk_find_selected_actor(ClutterActor *actor);
 
 //Signal functions
-void helpdesk_add_comment_to_question(ClutterActor *actor);
 void helpdesk_add_question(void);
 void helpdesk_view_question(ClutterActor *actor);
-void helpdesk_submit_button_pressed(void);
 
 void helpdesk_show_question_view(void);
-void helpdesk_show_comment_view(void);
 void helpdesk_show_helpdesk_view(void);
 void helpdesk_show_addquestion_view(void);
 
+void helpdesk_return_from_threads_view(GList *messagelist);
+
 typedef struct {
 	char sender[20];
 	char answer[150];
