@@ -174,6 +174,9 @@ void review_selected_song(ClutterActor *song){
 	
 	for(i = 0; i < 3 /*this should be the number of messages*/; i++){
 		msg = malloc(sizeof (message));
+
+		msg->index = 0; //Index of this question. 
+
 		msg->msg = malloc(strlen("Message#1")+1);
 		sprintf(msg->msg, "Message#%d", i+1);
 		strcpy(msg->avatar, "x");
@@ -203,7 +206,7 @@ void review_selected_song(ClutterActor *song){
 				clear_container(list);	
 				ClutterActor* mainview = jammo_get_actor_by_id("main-views-widget");
 				clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);
-				start_thread_view(messages, "jammosongs", NULL);
+				start_thread_view(messages, "jammosongs", NULL, 0);
 				
 				break;
 				}
@@ -241,9 +244,8 @@ void record_voice_comment(){
 
 	JammoBackingTrack* backing_track;
 	JammoRecordingTrack* recording_track;
-	
-	gchar* jammo_directory = configure_get_jammo_directory();
-	recording_filename = g_strdup_printf("%s/last_recorded.ogg",jammo_directory);
+
+	recording_filename = g_strdup_printf("%s/last_recorded.ogg",configure_get_jammo_directory());
 	//recording_filename = g_strdup_printf("/opt/jammo/last_recorded.ogg");
 	
 	jammo_meam_init(NULL, NULL, "jammo_test_duration_cache"); 	
@@ -257,7 +259,6 @@ void record_voice_comment(){
 	recording_track = jammo_recording_track_new_with_pitch_detect(recording_filename);
 	jammo_sequencer_add_track(sequencer, JAMMO_TRACK(recording_track)); 
 
-	g_free(jammo_directory);
 	g_print("Recording...\n");
 	g_print("Max length is 30 seconds.\n");
 
