@@ -11,6 +11,10 @@ This file contains the functionality of help menu.
 #include "mysongs.h"
 #include "community_utilities.h"
 
+#include "../../configure.h"
+#include "../file_helper.h"
+#include "sequencer.h" //From mysongs to sequencer
+
 static ClutterContainer *songlist = 0;
 static gint listItemHeight = 0;
 
@@ -18,7 +22,10 @@ void start_mysongs()
 {
 	puts("Starting Mysongs\n");
 
-	int numberOfLoops = 8;
+	int numberOfLoops = 0;
+	GList* l; //Iterator
+	GList* projects=NULL;
+	GList* finalized=NULL;
 
 	clutter_actor_hide(jammo_get_actor_by_id("communitymenu-view"));
 
@@ -32,6 +39,14 @@ void start_mysongs()
 	if(help_view)
 	{
 		clutter_actor_show(CLUTTER_ACTOR(help_view));
+		//Project-files:
+		projects = file_helper_get_all_files(configure_get_projects_directory());
+
+		//Audio-files:
+		finalized = file_helper_get_all_files(configure_get_finalized_directory());
+
+		numberOfLoops += g_list_length (projects) + g_list_length (finalized);
+
 
 		if(numberOfLoops > 5)
 			songlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("mysongs-songs-list-scrollable"));	
@@ -40,12 +55,25 @@ void start_mysongs()
 			songlist = CLUTTER_CONTAINER(jammo_get_actor_by_id("mysongs-songs-list-unscrollable"));	
 
 		clutter_actor_lower(CLUTTER_ACTOR(songlist),jammo_get_actor_by_id("mysongs_down-index"));
+		for (l = projects ; l; l = l->next)
+		{
+			mysongs_add_loop_to_list(l->data, 0); //0=project-file
+		}
+
+		for (l = finalized; l; l = l->next)
+		{
+			mysongs_add_loop_to_list(l->data, 1); //1=finalized file
+		}
+
+		if(numberOfLoops <= 6)
+			clutter_actor_set_height(CLUTTER_ACTOR(songlist), listItemHeight * numberOfLoops);
+
+		else
+			clutter_actor_set_height(CLUTTER_ACTOR(songlist), listItemHeight * 6);
 
-		for(int i = 0; i < numberOfLoops; i++)
-			mysongs_add_loop_to_list(NULL, i);	
 
 		ClutterAction *listAction = tangle_actor_get_action_by_type(CLUTTER_ACTOR(songlist), TANGLE_TYPE_SCROLL_ACTION);
-	
+
 		g_signal_connect_swapped(listAction, "clamp-offset-y", G_CALLBACK(mysongs_autoscroll_to_correct_pos), songlist);
 
 
@@ -81,35 +109,50 @@ void mysongs_autoscroll_to_correct_pos(ClutterActor *listToScroll)
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_OUT_QUAD, 300, "offset-y", (gfloat)(slot*listItemHeight), NULL);
 }
 
+static void start_sequencer_with_this_file(ClutterActor *actor, gpointer none) {
+	const char* filename = clutter_actor_get_name(actor);
+	sequencer_start_with_file((char*)filename);
+}
 
-gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops)
+/*
+ * Filename: contains fullpath
+ * Type:
+ * 0=work in progress (project)
+ * 1=finalized work (no editing anymore)
+ *
+ *TODO: filename is just printed.
+ */
+gboolean mysongs_add_loop_to_list(char* filename, int type)
 {
-	int type = 0;
-	int i;
 
 	ClutterActor *colorbar = clutter_texture_new_from_file("/opt/jammo/communitymenu/colorbar12.png",NULL);
-	ClutterActor *text = clutter_text_new_with_text("Courier 20", "Test");	
+	ClutterActor *text = clutter_text_new_with_text("Courier 20", filename);
 	ClutterActor *infoButton = NULL;
+	ClutterActor *textButton = NULL;
 
-	for(i = 0; i < numberOfLoops; i++)
-	{
-		if(type == 0) {//TODO Type of the button is determined by the state of the song eg. work in process, video missing etc.
+	textButton = tangle_button_new_with_background_actor(text);
+	clutter_actor_set_name(textButton,filename);
+
+	//Additinally of type, there can be another icon e.g. video missing, new comments
+		if(type == 0) {//TODO
 			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-				"/opt/jammo/communitymenu/community_comment_icon.png", NULL));
+				"/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
+
+			g_signal_connect (textButton, "clicked", G_CALLBACK (start_sequencer_with_this_file),NULL);
 		}
 		else if(type == 1) {
 			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
-				"/opt/jammo/communitymenu/community_mentor_icon.png", NULL));
+				"/opt/jammo/communitymenu/community_cdlabel.png", NULL));
 			clutter_actor_set_height(infoButton, clutter_actor_get_height(colorbar));
+			//g_signal_connect (textButton, "clicked", G_CALLBACK (jukebox_play_this),NULL); //TODO: implement
 		}
 		else {
 			infoButton = tangle_button_new_with_background_actor(clutter_texture_new_from_file(
 				"/opt/jammo/communitymenu/community_avatarbackground_small.png", NULL));
 		}
-		type++;
-	}
 
-	ClutterContainer *listContainer = clutter_group_new();
+
+	ClutterContainer *listContainer = CLUTTER_CONTAINER(clutter_group_new());
 
 	if(colorbar == NULL || infoButton == NULL)
 	{
@@ -122,7 +165,7 @@ gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops)
 	clutter_container_add_actor(listContainer, colorbar);		//Add components inside the container
 
 	clutter_actor_set_position(text, 60, 23);			
-	clutter_container_add_actor(listContainer, text);
+	clutter_container_add_actor(listContainer, textButton);
 	
 	clutter_actor_set_position(infoButton, 690, 0);
 	clutter_container_add_actor(listContainer, infoButton);
@@ -132,12 +175,6 @@ gboolean mysongs_add_loop_to_list(char* loopName, int numberOfLoops)
 
 	clutter_container_add_actor(songlist, CLUTTER_ACTOR(listContainer));
 
-	if(numberOfLoops <= 6)
-		clutter_actor_set_height(CLUTTER_ACTOR(songlist), listItemHeight * numberOfLoops);	
-
-	else
-		clutter_actor_set_height(CLUTTER_ACTOR(songlist), listItemHeight * 6);		
-
 	return TRUE;
 }
 
