@@ -181,64 +181,28 @@ static gint rpc_callback(const gchar* interface, const gchar* method, GArray* ar
 }
 #endif
 
-/* Be sure there are needed place to save compositions and singings.
+/*
+ Order of initialization:
+ * Configure (define directories and creates them if needed)
+ * CEM  (Logging)
+ * MEAN (audio)
+ * CHUM (graphical)
+ * GEMS (network)
+ * [N900: osso-context (+keep-a-live for display) ]
+ * gettext (locales)
+ * tangle-search-paths (e.g. json folders)
+ * Mentor-language
  */
-static void create_directories(void) {
-	gchar* cmd;
-	gchar* message;
-
-	gchar* compositions_directory = configure_get_compositions_directory();
-	cmd= g_strdup_printf("mkdir -p %s",compositions_directory);
-	if (system(cmd)) {
-		message = g_strdup_printf("Can't call '%s' ", cmd);
-		cem_add_to_log(message, J_LOG_ERROR);
-		g_free(message);
-	}
-	g_free(cmd);
-
-	cmd= g_strdup_printf("mkdir -p %s/7-12",compositions_directory); //Compositions for 7-12 game
-	if (system(cmd)) {
-		message = g_strdup_printf("Can't call '%s' ", cmd);
-		cem_add_to_log(message, J_LOG_ERROR);
-		g_free(message);;
-	}
-	g_free(cmd);
-
-	g_free(compositions_directory);
-	gchar* singings_directory = configure_get_singings_directory();
-
-	cmd = g_strdup_printf("mkdir -p %s",singings_directory);
-	if (system(cmd)) {
-		message = g_strdup_printf("Can't call '%s' ", cmd);
-		cem_add_to_log(message, J_LOG_ERROR);
-		g_free(message);
-	}
-	g_free(cmd);
-	
-	cmd = g_strdup_printf("mkdir -p %s/wavs",singings_directory);
-	if (system(cmd)) {
-		message = g_strdup_printf("Can't call '%s' ", cmd);
-		cem_add_to_log(message, J_LOG_ERROR);
-		g_free(message);;
-	}
-	g_free(cmd);
-
-	g_free(singings_directory);
-
-	//This is not directory but file!
-	gchar* jammo_directory = configure_get_jammo_directory();
-	cmd = g_strdup_printf("touch %s/pg-passwords",jammo_directory);
-	if (system(cmd)) {
-		message = g_strdup_printf("Can't call '%s' ", cmd);
-		cem_add_to_log(message, J_LOG_ERROR);
-		g_free(message);
-	}
-	g_free(cmd);
-	g_free(jammo_directory);
-
-}
-
 int main(int argc, char** argv) {
+	gchar* application_name;
+	//Name of binary
+	application_name = g_path_get_basename(argv[0]);
+	if (!strcmp(application_name, "jammo7_12") || (argc>=2 && strcmp(argv[1],"sequencer")==0)) {
+		configure_init_directories(FALSE);  //7-12 game
+	} else {
+		configure_init_directories(TRUE);  //3-6 game
+	}
+
 #ifdef N900
 	osso_context_t* osso_context;
 #endif
@@ -267,11 +231,9 @@ int main(int argc, char** argv) {
 	GObject* object;
 	ClutterActor* actor;
 	ClutterColor black = { 0, 0, 0, 255 };
-	gchar* application_name;
 	const gchar* duration_cache_filename;
 
 	//Name of binary
-	application_name = g_path_get_basename(argv[0]);
 	if (!strcmp(application_name, "jammo7_12") || (argc>=2 && strcmp(argv[1],"sequencer")==0)) {
 		duration_cache_filename = "jammo7_12.duration_cache";
 	} else {
@@ -318,8 +280,6 @@ int main(int argc, char** argv) {
 	g_timeout_add(55000, pause_display_blanking, osso_context);
 #endif
 
-	create_directories();
-
 	/* PACKAGE from configure.ac */ \
 	setlocale ( LC_ALL, "" );
 	bindtextdomain ( PACKAGE, "/opt/jammo/languages" );
@@ -459,6 +419,7 @@ int main(int argc, char** argv) {
 	g_object_unref(stylesheet);
 	
 	jammo_meam_cleanup();
+	configure_release_directories();
 
 #ifdef NETWORKING_ENABLED
 	/* PM logout */
