@@ -8,9 +8,7 @@ FILE *ink_F;
 void
 create_ink_head()
 {
-  gchar* jammo_directory = configure_get_jammo_directory();
-  gchar *filepath = g_build_filename(jammo_directory, "/motion_inkml.xml", NULL);
-  g_free(jammo_directory);
+  gchar *filepath = g_build_filename(configure_get_jammo_directory(), "/motion_inkml.xml", NULL);
   ink_F = fopen(filepath, "w");
 
   if(ink_F == NULL) {
