@@ -5,7 +5,7 @@
 #include <stdlib.h>
 
 static gint is_reset_passwd=0; 
-ClutterContainer *pg_login_screen_container;
+ClutterActor *pg_login_screen_container;
 
 gint get_is_reset_password ()
 {
@@ -23,7 +23,7 @@ static gboolean
 pg_on_reset_password (ClutterRectangle *rect, ClutterEvent *event, gpointer data)
 {
 	is_reset_passwd=1;	
-	clutter_actor_hide(CLUTTER_ACTOR(pg_login_screen_container));  
+	clutter_actor_hide(pg_login_screen_container);
  	return TRUE; 
 }
 
@@ -68,7 +68,7 @@ pg_on_continue_login (ClutterRectangle*actor, ClutterEvent *event, gpointer data
   gfloat x = 0;
   gfloat y = 0;
   clutter_event_get_coords (event, &x, &y);
-  clutter_actor_hide(CLUTTER_ACTOR(pg_login_screen_container));
+  clutter_actor_hide(pg_login_screen_container);
 
   return TRUE; 
 }
@@ -164,7 +164,7 @@ pg_set_select_option_screen(ClutterActor *stage)
 	clutter_actor_set_position (b_layer, 0, 0);
 	clutter_actor_set_size (b_layer, 800, 480);
 	clutter_actor_set_opacity(b_layer,220);
-  	clutter_container_add_actor (pg_login_screen_container, b_layer);
+	clutter_container_add_actor (CLUTTER_CONTAINER(pg_login_screen_container), b_layer);
 
 	// LOGIN
 	gchar* pg_directory_path = PG_IMAGES_DIR;
@@ -174,7 +174,7 @@ pg_set_select_option_screen(ClutterActor *stage)
 	clutter_actor_set_size (login_button, 151, 45);
 	clutter_actor_set_position (login_button, 30, 200);	
 	clutter_actor_show (login_button);
-	clutter_container_add_actor (pg_login_screen_container, login_button);
+	clutter_container_add_actor (CLUTTER_CONTAINER(pg_login_screen_container), login_button);
 	clutter_actor_set_reactive (login_button, TRUE);
 	g_signal_connect (login_button, "button-press-event", G_CALLBACK (pg_on_continue_login), NULL);
 	
