@@ -3,11 +3,15 @@
 #define _CONFIGURE_H_
 
 #include <glib.h>
-//get_jammo_directory is writable place for logs, passwords and saved singings/compositions
+void configure_init_directories(gboolean small_game);
+void configure_release_directories();
+
 gchar* configure_get_jammo_directory();
 gchar* configure_get_singings_directory();
 gchar* configure_get_compositions_directory();
 
+gchar* configure_get_projects_directory();
+gchar* configure_get_finalized_directory();
 /**
  * Defines default folders.
  */
