@@ -96,9 +96,6 @@ gboolean ProfileManager::Login(guint32 userID)
 // Logout
 gboolean ProfileManager::Logout()
 {
-	// Not logged in, cannot log out
-	if(!isAuthenticated()) return FALSE;
-	
 	// Clear the user from the memory
 	iUser = 0;
 	// Clear data (sets authenticated to FALSE)
@@ -106,7 +103,9 @@ gboolean ProfileManager::Logout()
 	// Clear encrypted data, should be saved before logout
 	iStorageAgent->clearEncryptedData();
 
-	return TRUE;
+	// Not logged in, cannot log out but clear the data just to avoid leaking
+	if(!isAuthenticated()) return FALSE;
+	else return TRUE;
 }
 
 string ProfileManager::ViewDetails()
