@@ -45,7 +45,25 @@ public:
 	// Get id
 	guint32 GetId();
 	
-	StorageAgent* GetStorageAgent();
+	gboolean loadEncryptedProfile(gchar* _username);
+	gboolean saveEncryptedProfile();
+	gboolean changeLoadedUser(gchar* _username);
+	gboolean deserializeProfile(gchar* _profile);
+	gchar* serializeProfile();
+	
+	guchar* getSalt();
+	guchar* getPasswordHash();
+	guchar* getProfileHash();
+	guchar* getEncryptedProfile();
+	guint getEncryptedProfileSize();
+	
+	gboolean setSalt(guchar* _salt);
+	gboolean setPasswordHash(guchar* _password_hash);
+	gboolean setEncryptedProfile(guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
+	
+	gboolean isSavingRequired();
+	gboolean isAuthenticated();
+	gboolean setAuthenticated();
 
 private:
 	
@@ -57,6 +75,7 @@ private:
 	StorageAgent *iStorageAgent;
 	//ProcessAgent *iProcessAgent;
 	guint32 iUser;
+	gboolean iSavingRequired;
 };
 
 #else
@@ -192,15 +211,25 @@ void profilemanager_reset_points(ProfileManager* _aManager);
 
 /* For encrypted profile data */
 
+gboolean profilemanager_storage_load_profile(ProfileManager* _aManager, gchar* _username);
+gboolean profilemanager_storage_save_profile(ProfileManager* _aManager);
+gboolean profilemanager_storage_change_profile(ProfileManager* _aManager, gchar* _username);
 guchar* profilemanager_storage_get_password_salt(ProfileManager* _aManager);
 guchar* profilemanager_storage_get_password_hash(ProfileManager* _aManager);
 guchar* profilemanager_storage_get_profile_hash(ProfileManager* _aManager);
 guchar* profilemanager_storage_get_encrypted_profile(ProfileManager* _aManager);
 guint profilemanager_storage_get_encrypted_profile_size(ProfileManager* _aManager);
-void profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt);
-void profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash);
-void profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
+gboolean profilemanager_storage_set_password_salt(ProfileManager* _aManager, guchar* _salt);
+gboolean profilemanager_storage_set_password_hash(ProfileManager* _aManager, guchar* _hash);
+gboolean profilemanager_storage_set_encrypted_profile(ProfileManager* _aManager, guchar* _profile_hash, guchar* _encrypted_profile, guint _e_profile_size);
 
+gboolean profilemanager_storage_deserialize_profile(ProfileManager* _aManager, guchar* _profile);
+gchar* profilemanager_storage_serialize_profile(ProfileManager* _aManager);
+
+gboolean profilemanager_set_authenticated(ProfileManager* _aManager);
+gboolean profilemanager_is_authenticated(ProfileManager* _aManager);
+
+gboolean profilemanager_is_saving_required(ProfileManager* _aManager);
 #ifdef __cplusplus
 }
 #endif
