@@ -42,8 +42,7 @@ StorageAgent::StorageAgent()
 	profileloaded = FALSE;
 	
 	gchar* logmsg = NULL;
-	gchar* jammopath = configure_get_jammo_directory();
-	gchar* path = g_build_filename(jammopath,JAMMOPROFILE,NULL);
+	gchar* path = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,NULL);
 	
 	// If profile directory exists
 	if(g_file_test(path,G_FILE_TEST_EXISTS))
@@ -65,7 +64,6 @@ StorageAgent::StorageAgent()
 				cem_add_to_log(logmsg,J_LOG_ERROR);
 				g_free(logmsg);
 				g_free(path);
-				g_free(jammopath);
 				return;	
 			}
 		}
@@ -73,7 +71,6 @@ StorageAgent::StorageAgent()
 		else
 		{
 			g_free(path);
-			g_free(jammopath);
 			return;
 		}
 	}
@@ -92,7 +89,6 @@ StorageAgent::StorageAgent()
 		g_free(logmsg);
 	}
 	g_free(path);
-	g_free(jammopath);
 }
 
 // Destructor
@@ -526,8 +522,7 @@ void StorageAgent::clearEncryptedData()
 gint StorageAgent::readProfile(gchar* username)
 {
 	gchar* profilefile = g_strjoin(NULL,username,PROFILE_FILE_EXT,NULL);
-	gchar* path = configure_get_jammo_directory();
-	gchar* filename = g_build_filename(path,JAMMOPROFILE,profilefile,NULL);
+	gchar* filename = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,profilefile,NULL);
 	gchar* contents = NULL;
 	guint length = 0;
 	GError* error = NULL;
@@ -552,7 +547,6 @@ gint StorageAgent::readProfile(gchar* username)
 				g_error_free(error);
 				g_free(profilefile);
 				g_free(filename);
-				g_free(path);
 				return 1;
 			}
 		}
@@ -599,14 +593,12 @@ gint StorageAgent::readProfile(gchar* username)
 		g_free(logmsg);
 		g_free(filename);
 		g_free(profilefile);
-		g_free(path);
 		return 2;
 	}
   
 	g_free(contents);
 	g_free(filename);
 	g_free(profilefile);
-	g_free(path);
 
 	return 0;
 }
@@ -616,8 +608,7 @@ gint StorageAgent::readProfile(gchar* username)
 gint StorageAgent::writeProfile(gchar* username)
 {
 	gchar* profilefile = g_strjoin(NULL,username,PROFILE_FILE_EXT,NULL);
-	gchar* path = configure_get_jammo_directory();
-	gchar* filename = g_build_filename(path,JAMMOPROFILE,profilefile,NULL);
+	gchar* filename = g_build_filename(configure_get_jammo_directory(),JAMMOPROFILE,profilefile,NULL);
 	guint length = AES_SALT_LENGTH + SHA_HASH_LENGTH + SHA_HASH_LENGTH + encrypted_profile_size;
 	GError* error = NULL;
 	gchar* logmsg = NULL;
@@ -665,7 +656,6 @@ gint StorageAgent::writeProfile(gchar* username)
 			g_free(filename);
 			g_free(profilefile);
 			g_free(content);
-			g_free(path);
 			return -1;
 		}
 	}
@@ -681,7 +671,6 @@ gint StorageAgent::writeProfile(gchar* username)
 			g_free(filename);
 			g_free(profilefile);
 			g_free(content);
-			g_free(path);
 			return -1;
 		}
   }
@@ -695,7 +684,6 @@ gint StorageAgent::writeProfile(gchar* username)
 	g_free(content);
 	g_free(filename);
 	g_free(profilefile);
-	g_free(path);
 	
 	return 0;
 }
