@@ -37,7 +37,6 @@
 
 GTimer* testtimer;
 
-
 gems_communication_data* gems_communication_init()
 {
 	// Communication data struct
@@ -708,6 +707,8 @@ gint gems_communication_process_connected()
 {
 	gems_components* data = gems_get_data();
 	gboolean cleanup_required = FALSE;
+	gboolean teacher_cleanup_required = FALSE;
+	gboolean do_teacher_check = FALSE;
 	gems_connection* element = NULL;
 	GList* iterator = NULL;
 	gchar* logmsg = NULL;
@@ -717,14 +718,20 @@ gint gems_communication_process_connected()
 	if(data->ph == NULL) return FALSE;
 	if(data->communication == NULL) return FALSE;
 	
+	// Check if we have a teacher connection
+	if(gems_teacher_connection_is_connected()) do_teacher_check = TRUE;
+	
 	iterator = g_list_first(data->communication->connections);
-	while(iterator)
+	while(iterator || do_teacher_check)
 	{
-		element = (gems_connection*)iterator->data;
+		// If we have a active connection to teacher, check for incoming data
+		if(do_teacher_check) element = data->teacher_connection->connection;
+		else element = (gems_connection*)iterator->data;
 		
 		if(!element)
 		{
-			iterator = g_list_next(iterator);
+			if(do_teacher_check) do_teacher_check = FALSE;
+			else iterator = g_list_next(iterator);
 			continue;
 		}
 		
@@ -759,7 +766,8 @@ gint gems_communication_process_connected()
 							cem_add_to_log(logmsg, J_LOG_ERROR);
 							g_free(logmsg);
 							ph_c_connection_disconnect(element->connection);
-							cleanup_required = TRUE;
+							if(do_teacher_check) teacher_cleanup_required = TRUE;
+							else cleanup_required = TRUE;
 							break;
 					}
 				}
@@ -785,7 +793,8 @@ gint gems_communication_process_connected()
 							g_free(logmsg);
 							
 							ph_c_connection_disconnect(element->connection);
-							cleanup_required = TRUE;
+							if(do_teacher_check) teacher_cleanup_required = TRUE;
+							else cleanup_required = TRUE;
 							break;
 					}
 				}
@@ -821,7 +830,8 @@ gint gems_communication_process_connected()
 						g_free(logmsg);
 						
 						ph_c_connection_disconnect(element->connection);
-						cleanup_required = TRUE;
+						if(do_teacher_check) teacher_cleanup_required = TRUE;
+						else cleanup_required = TRUE;
 					}
 				}
 				
@@ -832,7 +842,8 @@ gint gems_communication_process_connected()
 					if(gems_communication_process_data(element) == FALSE)
 					{
 						ph_c_connection_disconnect(element->connection);
-						cleanup_required = TRUE;
+						if(do_teacher_check) teacher_cleanup_required = TRUE;
+						else cleanup_required = TRUE;
 					}
 				}
 				
@@ -843,7 +854,8 @@ gint gems_communication_process_connected()
 					g_free(logmsg);
 					
 					ph_c_connection_disconnect(element->connection);
-					cleanup_required = TRUE;
+					if(do_teacher_check) teacher_cleanup_required = TRUE;
+					else cleanup_required = TRUE;
 				}
 			}
 			
@@ -869,7 +881,9 @@ gint gems_communication_process_connected()
 								case JAMMO_PACKET_GROUP:
 									gems_connection_add_16(element,identifier);
 									break;
-								//case JAMMO_PACKET_ADMIN:
+								case JAMMO_PACKET_ADMIN:
+									gems_connection_add_16(element,identifier);
+									break;
 								case ERROR_MSG:
 									gems_connection_add_16(element,identifier);
 									break;
@@ -897,7 +911,8 @@ gint gems_communication_process_connected()
 								}
 								gems_clear_message(err);
 								ph_c_connection_disconnect(element->connection);
-								cleanup_required = TRUE;
+								if(do_teacher_check) teacher_cleanup_required = TRUE;
+								else cleanup_required = TRUE;
 							}
 							// TODO check that AA service is running
 						}
@@ -910,15 +925,19 @@ gint gems_communication_process_connected()
 						cem_add_to_log(logmsg, J_LOG_ERROR);
 						g_free(logmsg);
 						ph_c_connection_disconnect(element->connection);
-						cleanup_required = TRUE;
+						if(do_teacher_check) teacher_cleanup_required = TRUE;
+						else cleanup_required = TRUE;
 						break;
 				}
 			}
 		}
 		
-		iterator = g_list_next(iterator);
+		// Done once during this function execution
+		if(do_teacher_check) do_teacher_check = FALSE;
+		else iterator = g_list_next(iterator);
 	}
 	if(cleanup_required == TRUE) data->communication->connections = gems_cleanup_connections_from_list(data->communication->connections);
+	if(teacher_cleanup_required) gems_teacher_connection_disconnect();
 	
 	return TRUE;
 }
@@ -969,6 +988,17 @@ gboolean gems_communication_process_data(gems_connection* element)
 			case JAMMO_PACKET_GROUP:
 				break;
 			case JAMMO_PACKET_ADMIN:
+				switch(gems_security_extract_envelope(element))
+				{
+					case SECURITY_OK:
+						break;
+					case SECURITY_VERIFY_FAILED:
+						break;
+					case SECURITY_CORRUPT_MESSAGE:
+						break;
+					default:
+						break;
+				}
 				break;
 			default:
 				logmsg = g_strdup_printf("gems_communication_process_data: unknown envelope id (%d) from authenticated user",ntohs(gems_connection_get_16(element,0)));
@@ -1007,19 +1037,38 @@ gboolean gems_communication_process_data(gems_connection* element)
 			success = FALSE; // TODO change to add a "invalid message" to errors
 			break;
 		case PROFILE_SERVICE_ID:
-			// Check that service is running
-			if(data->service_profile->enabled == TRUE) success = gems_service_profile_process_request(element);
+			if(gems_connection_get_16(element,sizeof(gint16)+sizeof(gint32)) == PROFILE_ENC)
+			{
+				// If the message cannot be processed it from some one else than teacher
+				if(!gems_service_profile_process_profile_upload(element))
+				{
+					err = gems_create_error_message(ERROR_INVALID_ACCESS_TYPE, TEACHER_PROFILE_SERVICE_ID);
+					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
+					{
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_INVALID_ACCESS_TYPE");
+						cem_add_to_log(logmsg, J_LOG_ERROR);
+						g_free(logmsg);
+					}
+					gems_clear_message(err);
+					success = FALSE;
+				}
+			}
 			else
 			{
-				err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, PROFILE_SERVICE_ID);
-				if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
+				// Check that service is running
+				if(data->service_profile->enabled == TRUE) success = gems_service_profile_process_request(element);
+				else
 				{
-					logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
-					cem_add_to_log(logmsg, J_LOG_ERROR);
-					g_free(logmsg);
+					err = gems_create_error_message(ERROR_SERVICE_NOT_RUNNING_TYPE, PROFILE_SERVICE_ID);
+					if(gems_communication_write_data(ph_c_connection_get_fd(element->connection),err) != err->length)
+					{
+						logmsg = g_strdup_printf("gems_service_jammo_process_connections: cannot write ERROR_SERVICE_NOT_RUNNING");
+						cem_add_to_log(logmsg, J_LOG_ERROR);
+						g_free(logmsg);
+					}
+					gems_clear_message(err);
+					success = FALSE; // TODO change to add a "invalid message" to errors
 				}
-				gems_clear_message(err);
-				success = FALSE; // TODO change to add a "invalid message" to errors
 			}
 			break;
 		case GROUP_SERVICE_ID:
@@ -1507,24 +1556,58 @@ gems_teacher_connection* gems_teacher_connection_init()
 	
 	return tc;
 }
+
+gboolean gems_teacher_connection_disconnect()
+{
+	gems_components* data = gems_get_data();
+	
+	if(data == NULL) return FALSE;
+	if(data->teacher_connection == NULL) return FALSE; 
+	
+	// gems_connection exists
+	if(data->teacher_connection->connection != NULL)
+	{
+		gems_clear_gems_connection(data->teacher_connection->connection);
+		data->teacher_connection->connection = NULL;
+		
+		gchar* logmsg = g_strdup_printf("gems_teacher_connection_disconnect: connection to teacher was disconnected");
+		cem_add_to_log(logmsg,J_LOG_DEBUG);
+		g_free(logmsg);
+		return TRUE;
+	}
+	else return FALSE;
+}
+
 void gems_clear_teacher_connection()
 {
 	gems_components* data = gems_get_data();
 	
 	if(data == NULL) return;
-	if(data->teacher_connection == NULL) return;
+	if(data->teacher_connection == NULL) return; 
+	
+	// gems_connection exists
 	if(data->teacher_connection->connection != NULL)
 	{
-		if(ph_c_connection_disconnect(data->teacher_connection->connection))
-		{
-			gchar* logmsg = g_strdup_printf("gems_clear_teacher_connection: connection to teacher was disconnected");
-			cem_add_to_log(logmsg,J_LOG_DEBUG);
-			g_free(logmsg);
-		}
-		ph_c_connection_delete(data->teacher_connection->connection);
+		gems_clear_gems_connection(data->teacher_connection->connection);
 		data->teacher_connection->connection = NULL;
+		
+		gchar* logmsg = g_strdup_printf("gems_clear_teacher_connection: connection to teacher was disconnected");
+		cem_add_to_log(logmsg,J_LOG_DEBUG);
+		g_free(logmsg);
 	}
+	
 	g_free(data->teacher_connection);
 	data->teacher_connection = NULL;
 	
 }
+
+gboolean gems_communication_do_profile_request_to_teacher(gchar* username)
+{
+	gboolean rval = TRUE;
+	gems_message* msg = gems_create_message_teacher_service_profile_request(username);
+	if(gems_teacher_connection_is_connected()) rval = gems_communication_write_encrypted_data(JAMMO_PACKET_PRIVATE,gems_get_teacher_connection()->connection,msg);
+	else rval = FALSE;
+	gems_clear_message(msg);
+	
+	return rval;
+}
