@@ -127,6 +127,22 @@ gems_teacher_connection* gems_get_teacher_connection()
 	return gems_get_data()->teacher_connection;
 }
 
+gboolean gems_teacher_connection_is_connected()
+{
+	if(gems_get_teacher_connection() != NULL)
+	{
+		if(gems_get_teacher_connection()->connection != NULL)
+		{
+			if(gems_get_teacher_connection()->connection->connection != NULL)
+			{
+				// Teacher is connected?
+				if(ph_c_connection_is_connected(gems_get_teacher_connection()->connection->connection)) return TRUE;
+			}
+		}
+	}
+	return FALSE;
+}
+
 void gems_free_data()
 {
 	if(gems_data)
@@ -503,7 +519,8 @@ void gems_ph_callback_newconnection(const unsigned short aPort, MAbstractConnect
 				{
 					if(components->teacher_connection->connection == NULL)
 					{
-						components->teacher_connection->connection = aConnection;
+						// TODO set proper teacher authentication state
+						components->teacher_connection->connection = gems_new_gems_connection(aConnection, aPort, aConnectionId, JAMMO_CONNECTED_NO_AUTH, 0);
 						logmsg = g_strdup_printf("gems_ph_callback_newconnection: TEACHER CONNECTED from %s", ph_c_connection_get_remote_address(aConnection));
 						cem_add_to_log(logmsg,J_LOG_NETWORK_DEBUG);
 						g_free(logmsg);
