@@ -118,6 +118,8 @@ typedef enum
 #define MENTOR_SERVICE_ID 107
 #define CONTROL_SERVICE_ID 108
 #define PROBE_SERVICE_ID 109
+#define TEACHER_PROFILE_SERVICE_ID PROFILE_SERVICE_ID
+
 
 /*-----------  Service Names ----------*/
 #define JAMMO_SERVICE_NAME "JamMo"
@@ -131,6 +133,12 @@ typedef enum
 #define CONTROL_SERVICE_NAME JAMMO_SERVICE_NAME ":Control"
 #define PROBE_SERVICE_NAME JAMMO_SERVICE_NAME ":ProbeVerification"
 
+// Generic teacher server name
+#define TEACHER_SERVICE_NAME JAMMO_SERVICE_NAME ":TeacherServer"
+// Teacher profile service
+#define TEACHER_PROFILE_SERVICE_NAME TEACHER_SERVICE_NAME ":Profile"
+
+
 
 /*-----------  Command types ----------*/
 
@@ -160,6 +168,9 @@ typedef enum
 #define PROFILE_FULL 1023
 #define GET_PROFILE_PUB 1024
 #define GET_PROFILE_FULL 1025
+#define REQ_ENC_PROFILE 1026
+#define PROFILE_ENC 1027
+#define PROFILE_SET_UNAME 1028
 
 // GROUP SERVICE
 #define REQUEST_MEMBERS 1030
