@@ -243,6 +243,74 @@ gems_message* gems_create_message_profile_request(gint16 type)
 	return msg;
 }
 
+gems_message* gems_create_message_teacher_service_profile_request(gchar* username)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + strlen(username) + 1;
+	
+	msg->message = (gchar*)g_malloc(sizeof(gchar*) * msg->length);
+	
+	memset(msg->message,'\0',msg->length);
+	
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(TEACHER_PROFILE_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(REQ_ENC_PROFILE);
+	position = position + sizeof(gint16);
+	
+	// Username
+	g_strlcat(&msg->message[position],username,strlen(username)+1);
+	position = position + strlen(username) + 1;
+	
+	return msg;
+}
+
+gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, guint length, gchar* username)
+{
+	gems_message* msg = (gems_message*)g_malloc(sizeof(gems_message));
+	guint position = 0;
+	gint16 unamelen = strlen(username) + 1; // 1 NULL to separate username and encrypted profile
+	
+	msg->length = sizeof(gint16) + sizeof(gint32) + sizeof(gint16) + sizeof(gint16) + unamelen + length ;
+	
+	msg->message = (gchar*)g_malloc0(sizeof(gchar*) * msg->length);
+	
+	// Service id 16 bits
+	*(gint16*)&msg->message[position] = g_htons(TEACHER_PROFILE_SERVICE_ID);
+	position = position + sizeof(gint16);
+	
+	// Length 32 bits
+	*(gint32*)&msg->message[position] = g_htonl(msg->length);
+	position = position + sizeof(gint32);
+	
+	// Command 16 bits
+	*(gint16*)&msg->message[position] = g_htons(PROFILE_ENC);
+	position = position + sizeof(gint16);
+	
+	// Username length
+	*(gint16*)&msg->message[position] = g_htons(unamelen);
+	position = position + sizeof(gint16);
+	
+	// Username
+	g_strlcat(&msg->message[position],username,unamelen); 
+	position = position + unamelen;
+	
+	// Encrypted profile data
+	g_memmove(&msg->message[position],data,length);
+	position = position + length;
+	
+	return msg;
+}
+
+
 /* Use with notify messages which do not need the group information, for sending:
 		- REQUEST_GROUP_INFO
 		- REQUEST_MEMBERS
