@@ -25,6 +25,10 @@ gems_message* gems_create_message_service_profile(gint16 type);
 
 gems_message* gems_create_message_profile_request(gint16 type);
 
+gems_message* gems_create_message_teacher_service_profile_request(gchar* username);
+
+gems_message* gems_create_message_teacher_service_profile_reply(gchar* data, guint length, gchar* username);
+
 gems_message* gems_create_message_group_management_notify(gint16 type, guint32 groupid, guint32 member);
 
 gems_message* gems_create_message_group_management_group_info(gint16 type);
