@@ -403,6 +403,15 @@ void gems_connection_localize_data_in_buffer(gems_connection* element)
 					break;
 				case PROFILE_FULL:
 					break;
+				case REQ_ENC_PROFILE:
+					// Should contain username after 16+32+16 bits, no conversion
+					break;
+				case PROFILE_ENC:
+					// Username length
+					gems_connection_add_16(element, g_ntohs(gems_connection_get_16(element,element->add_position)));
+					break;
+				case PROFILE_SET_UNAME:
+					break;
 				default:
 					break;
 			}
