@@ -85,7 +85,7 @@ void jammo_editing_track_add_sample(JammoEditingTrack* editing_track, JammoSampl
 	loop = g_malloc(sizeof(JammoLooperLoop));
 	memset(loop, 0, sizeof(JammoLooperLoop));
 	loop->filename = g_strdup(jammo_sample_get_real_filename(sample));
-	printf("real filename of sample is '%s'\n",loop->filename);
+	//printf("real filename of sample is '%s'\n",loop->filename);
 	loop->start = position;
 	g_object_set(editing_track->priv->looper, "add-loop", loop, NULL);
 	g_free(loop->filename);
