@@ -133,14 +133,12 @@ void jammo_meam_init(int* argc, char** argv[], const gchar* duration_cache_filen
 
 		cached_durations_filename = g_strdup(duration_cache_filename);
 	} else {
-		gchar* jammo_directory=configure_get_jammo_directory();
-		path = g_build_filename(jammo_directory, duration_cache_filename, NULL);
+		path = g_build_filename(configure_get_jammo_directory(), duration_cache_filename, NULL);
 		if (!g_file_test(path, G_FILE_TEST_EXISTS)) {
 			g_free(path);
 			path = g_build_filename(DATA_DIR, duration_cache_filename, NULL);
 		}
-		cached_durations_filename = g_build_filename(jammo_directory, duration_cache_filename, NULL);
-		g_free(jammo_directory);
+		cached_durations_filename = g_build_filename(configure_get_jammo_directory(), duration_cache_filename, NULL);
 	}
 	if (load_cached_durations(path)) {
 		cached_durations_changed = FALSE;
