@@ -15,6 +15,7 @@
 #include <string.h>
 #include <tangle.h>
 
+#include "../configure.h"
 enum {
 	PROP_0,
 	PROP_FILENAME,
@@ -719,10 +720,19 @@ static void initialize_state(JammoSample* sample) {
 			
 		//printf("file: %s\n",filename);
 		gchar* filename_with_path;
-		filename_with_path=tangle_lookup_filename(filename);
+
+		//If filename is absolute, use it as filename_with_path
+		if (filename[0] == '/' ) {
+			filename_with_path= g_strdup_printf("%s",filename);
+		}
+		else { //If it is relative, add AUDIO_DIR prefix
+			//printf("adding AUDIO_DIR\n");
+			filename_with_path= g_strdup_printf("%s/%s",AUDIO_DIR,filename);
+		}
 		sample->priv->real_filename = g_strdup(filename_with_path);
-		g_free(filename_with_path);
 		//printf("file_with_path: %s\n", filename_with_path);
+		g_free(filename_with_path);
+
 
 		if (sample->priv->element) {
 			g_object_set(sample->priv->element,
